# Description of the module:

This module had been created to simplify the code available on https://github.com/MISP/misp-privacy-aware-exchange and to create an export module.
This is also intended to make easier the creation of an integrated export module in MISP.

The module pypraware_misp (python privacy aware for MISP) is separated into two different subparts, the first is used for the "crypto systems" called pypraware_crypto while the second one is used for normalisation and is called pypraware_normalize.